# dha-rating

This package is a React component to submit an app review and rating that saves to CosmosDB using the dha-rating-api with Azure Functions.

## Getting Started

#### Install

Install from npm:

- npm i dha-rating @mui/material @mui/lab @emotion/react @emotion/styled

#### CORS Access

- This package will work on localhost:3000. For any applications that are hosted or using a different URL please contact someone from the SDK team to allow CORS access.

#### Rating Component

Rating Props:

- appId: App id for application reviewed

Home.tsx - Functional component

```javascript
import { Rating } from 'dha-rating';
import React from 'react';

const Home: React.FC = () => <Rating appId="MoodTracker" />;

export default Home;
```

## Contribute

#### Setup

- SSH: git clone git@bitbucket.org:wmtp/dha-rating.git
- HTTPS: git clone https://username@bitbucket.org/wmtp/dha-rating.git
- cd dha-rating
- git checkout dev (if necessary, never work directly in master branch)
- npm i

#### Build

The package uses the Typescript compiler (TSC) to build the source code. To build the project run the following command:

- npm run build

#### Link peerDependencies

Note: You must tell the local dha-rating to use all peerDependencies from the app you are including the dha-rating into using npm link (the example below is for using the dha-rating in the pwa-starter).

See the dha-rating package.json peerDependencies section.

```json
"peerDependencies": {
  "@emotion/react": "^X.X.X",
  "@emotion/styled": "^X.X.X",
  "@mui/lab": "^X.X.X",
  "@mui/material": "^X.X.X",
  "react": "^X.X.X",
  "react-dom": "^X.X.X"
}
```

- npm link ../pwa-starter/node_modules/@emotion/react
- npm link ../pwa-starter/node_modules/@emotion/styled
- npm link ../pwa-starter/node_modules/@mui/lab
- npm link ../pwa-starter/node_modules/@mui/material
- npm link ../pwa-starter/node_modules/react
- npm link ../pwa-starter/node_modules/react-dom
- Repeat for any remaining peerDependencies that are not listed.

#### Install Local

You can install the package into your own React application/pwa-starter as a dependency. After you build the dha-rating, install the package into the app using the following command:

- cd pwa-starter
- npm i /abs/or/rel/path/to/dha-rating or npm link /abs/or/rel/path/to/dha-rating
  - ex. npm i ../dha-rating or npm link ../dha-rating
    - pwa-starter and dha-rating are sibling folders in the example. Adjust this to your project name and directory structure.

#### Troubleshooting

Npm Install Issues

- Clearing the package-lock.json and node_modules folder can help ensure that an app or package starts in a clean state.
  - rm -rf package-lock.json node_modules

Hook Errors

- Hook errors can be caused when a local package is installed into an application where the package devDependencies conflict with the application dependencies by having multiple instances of the same dependency.
- You must tell the local dha-rating to use peerDependencies from the app you are including the dha-rating into using npm link (the example below is for using the dha-rating in the pwa-starter).
  - Refer to "Link peerDependencies" section above.
    - npm link ../pwa-starter/node_modules/@mui/material

#### Test

- Tests can be ran with the `npm test` command.
- Tests are ran using Jest with Enzyme - More information about getting started with Jest can be found [here](https://jestjs.io/docs/en/getting-started.html).

Example:

```javascript
test('renders without crashing', () => {
  shallow(<Rating prop1="1" prop2={2} />);
});

test('hello world string', () => {
  expect(demo()).toMatch(`RENAME Demo files to start.`);
});
```

## Source Code

https://bitbucket.org/wmtp/dha-rating

## NPM

https://www.npmjs.com/package/dha-rating

## License

This project is licensed under the MIT License.
